# neuro-py

Analysis of neuroelectrophysiology data in Python.

## Installation

```bash
pip install neuro-py
```

## Usage

```python
import neuro_py as neuro
```

## Development

```bash
git clone
cd neuro_py
pip install -e .
```

## Dependencies 

This package uses nelpy for its core data objects. See [nelpy](https://github.com/nelpy/nelpy) 

## Testing

```bash
pytest
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## Authors

- [@ryanharvey1](https://www.github.com/ryanharvey1)
- [@lolaBerkowitz](https://www.github.com/lolaBerkowitz)


## License

neuro_py is distributed under the MIT license. See the [LICENSE](https://github.com/neuro_py/neuro_py/blob/master/LICENSE) file for details.
